@@ -1,3 +1,5 @@
+import typing
+
 import requests
 
 from .base import BaseHTTPClient
@@ -23,3 +25,11 @@ class SyncHTTPClient(BaseHTTPClient):
             except requests.HTTPError as error:
                 raise HTTPError.from_requests(error, data) from None
             return data
+
+    def set_cookie(
+        self,
+        name: str,
+        value: typing.Optional[str] = None,
+        domain: str = "www.codingame.com",
+    ):
+        return self.__session.cookies.set(name, value, domain=domain)
